@@ -78,22 +78,23 @@ def _get_inventory_paths(parsed_args, inventory_filename):
     else:
         paths = [os.path.join(parsed_args.kolla_config_path, "inventory",
                               inventory_filename)]
-
-        def append_path(directory):
-            candidate_path = os.path.join(
-                parsed_args.kolla_config_path, "extra-inventories",
-                directory)
-            if utils.is_readable_dir(candidate_path)["result"]:
-                paths.append(candidate_path)
-
         # Inventory in the base layer is placed in the "kayobe"
         # directory. This means that you can't have an environment
         # called kayobe as it would conflict.
-        append_path("kayobe")
-
+        environments = ["kayobe"]
         if parsed_args.environment:
-            append_path(parsed_args.environment)
-
+            environments.append(parsed_args.environment)
+        else:
+            environment_finder = utils.EnvironmentFinder(
+                parsed_args.config_path, parsed_args.environment)
+            for environment in environment_finder.ordered():
+                environments.append(environment)
+        for environment in environments:
+            candidate_path = os.path.join(
+                parsed_args.kolla_config_path, "extra-inventories",
+                environment)
+            if utils.is_readable_dir(candidate_path)["result"]:
+                paths.append(candidate_path)
         return paths
 
 
