@@ -12,6 +12,8 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
+import glob
+import os
 import unittest
 from unittest import mock
 
@@ -62,7 +64,8 @@ class TestCase(unittest.TestCase):
                 mock.ANY,
                 [utils.get_data_files_path("ansible", "kolla-ansible.yml")],
                 tags="install",
-                ignore_limit=True
+                ignore_limit=True,
+                check=False,
             ),
         ]
         self.assertListEqual(expected_calls, mock_run.call_args_list)
@@ -95,7 +98,8 @@ class TestCase(unittest.TestCase):
                 mock.ANY,
                 [utils.get_data_files_path("ansible", "kolla-ansible.yml")],
                 tags=None,
-                ignore_limit=True
+                ignore_limit=True,
+                check=False,
             ),
             mock.call(
                 mock.ANY,
@@ -140,7 +144,8 @@ class TestCase(unittest.TestCase):
                 mock.ANY,
                 [utils.get_data_files_path("ansible", "kolla-ansible.yml")],
                 tags="install",
-                ignore_limit=True
+                ignore_limit=True,
+                check=False,
             ),
         ]
         self.assertListEqual(expected_calls, mock_run.call_args_list)
@@ -805,17 +810,20 @@ class TestCase(unittest.TestCase):
             mock.call(
                 mock.ANY,
                 [utils.get_data_files_path("ansible", "seed-deploy-containers.yml")],  # noqa
+                extra_vars={'kayobe_action': 'deploy'}
             ),
             mock.call(
                 mock.ANY,
                 [utils.get_data_files_path("ansible", "kolla-ansible.yml")],
                 tags="config",
                 ignore_limit=True,
+                check=False,
             ),
             mock.call(
                 mock.ANY,
                 [utils.get_data_files_path("ansible", "kolla-bifrost.yml")],
                 ignore_limit=True,
+                check=False,
             ),
             mock.call(
                 mock.ANY,
@@ -827,6 +835,7 @@ class TestCase(unittest.TestCase):
                     utils.get_data_files_path(
                         "ansible", "dell-switch-bmp.yml"),
                 ],
+                extra_vars={'kayobe_action': 'deploy'}
             ),
         ]
         self.assertListEqual(expected_calls, mock_run.call_args_list)
@@ -855,17 +864,20 @@ class TestCase(unittest.TestCase):
             mock.call(
                 mock.ANY,
                 [utils.get_data_files_path("ansible", "seed-deploy-containers.yml")],  # noqa
+                extra_vars={'kayobe_action': 'deploy'}
             ),
             mock.call(
                 mock.ANY,
                 [utils.get_data_files_path("ansible", "kolla-ansible.yml")],
                 tags="config",
                 ignore_limit=True,
+                check=False,
             ),
             mock.call(
                 mock.ANY,
                 [utils.get_data_files_path("ansible", "kolla-bifrost.yml")],
                 ignore_limit=True,
+                check=False,
             ),
             mock.call(
                 mock.ANY,
@@ -1120,6 +1132,7 @@ class TestCase(unittest.TestCase):
                 [utils.get_data_files_path("ansible", "kolla-ansible.yml")],
                 tags="config",
                 ignore_limit=True,
+                check=False,
             ),
         ]
         self.assertListEqual(expected_calls, mock_run.call_args_list)
@@ -1218,6 +1231,7 @@ class TestCase(unittest.TestCase):
                 [utils.get_data_files_path("ansible", "kolla-ansible.yml")],
                 tags="config",
                 ignore_limit=True,
+                check=False,
             ),
         ]
         self.assertListEqual(expected_calls, mock_run.call_args_list)
@@ -1428,6 +1442,7 @@ class TestCase(unittest.TestCase):
                 [utils.get_data_files_path("ansible", "kolla-ansible.yml")],
                 tags="config",
                 ignore_limit=True,
+                check=False,
             ),
         ]
         self.assertListEqual(expected_calls, mock_run.call_args_list)
@@ -1459,6 +1474,7 @@ class TestCase(unittest.TestCase):
                 [utils.get_data_files_path("ansible", "kolla-ansible.yml")],
                 tags="config",
                 ignore_limit=True,
+                check=False,
             ),
         ]
         self.assertListEqual(expected_calls, mock_run.call_args_list)
@@ -1489,6 +1505,7 @@ class TestCase(unittest.TestCase):
                 [utils.get_data_files_path("ansible", "kolla-ansible.yml")],
                 tags="config",
                 ignore_limit=True,
+                check=False,
             ),
             mock.call(
                 mock.ANY,
@@ -1497,6 +1514,7 @@ class TestCase(unittest.TestCase):
                                               "kolla-openstack.yml"),
                 ],
                 ignore_limit=True,
+                check=False,
             ),
         ]
         self.assertListEqual(expected_calls, mock_run.call_args_list)
@@ -1528,6 +1546,7 @@ class TestCase(unittest.TestCase):
                 [utils.get_data_files_path("ansible", "kolla-ansible.yml")],
                 tags="config",
                 ignore_limit=True,
+                check=False,
             ),
             mock.call(
                 mock.ANY,
@@ -1536,6 +1555,7 @@ class TestCase(unittest.TestCase):
                                               "kolla-openstack.yml"),
                 ],
                 ignore_limit=True,
+                check=False,
             ),
         ]
         self.assertListEqual(expected_calls, mock_run.call_args_list)
@@ -1589,6 +1609,7 @@ class TestCase(unittest.TestCase):
                 [utils.get_data_files_path("ansible", "kolla-ansible.yml")],
                 ignore_limit=True,
                 tags="config",
+                check=False,
             ),
             mock.call(
                 mock.ANY,
@@ -1597,6 +1618,7 @@ class TestCase(unittest.TestCase):
                                               "kolla-openstack.yml"),
                 ],
                 ignore_limit=True,
+                check=False,
             ),
             mock.call(
                 mock.ANY,
@@ -1654,6 +1676,7 @@ class TestCase(unittest.TestCase):
                 [utils.get_data_files_path("ansible", "kolla-ansible.yml")],
                 ignore_limit=True,
                 tags="config",
+                check=False,
             ),
             mock.call(
                 mock.ANY,
@@ -1662,6 +1685,7 @@ class TestCase(unittest.TestCase):
                                               "kolla-openstack.yml"),
                 ],
                 ignore_limit=True,
+                check=False,
             ),
             mock.call(
                 mock.ANY,
@@ -1707,6 +1731,7 @@ class TestCase(unittest.TestCase):
                 [utils.get_data_files_path("ansible", "kolla-ansible.yml")],
                 ignore_limit=True,
                 tags="config",
+                check=False,
             ),
             mock.call(
                 mock.ANY,
@@ -1715,6 +1740,7 @@ class TestCase(unittest.TestCase):
                                               "kolla-openstack.yml"),
                 ],
                 ignore_limit=True,
+                check=False,
             ),
         ]
         self.assertListEqual(expected_calls, mock_run.call_args_list)
@@ -1745,6 +1771,7 @@ class TestCase(unittest.TestCase):
                 [utils.get_data_files_path("ansible", "kolla-ansible.yml")],
                 ignore_limit=True,
                 tags="config",
+                check=False,
             ),
             mock.call(
                 mock.ANY,
@@ -1753,6 +1780,7 @@ class TestCase(unittest.TestCase):
                                               "kolla-openstack.yml"),
                 ],
                 ignore_limit=True,
+                check=False,
             ),
             mock.call(
                 mock.ANY,
@@ -1809,6 +1837,7 @@ class TestCase(unittest.TestCase):
                 [utils.get_data_files_path("ansible", "kolla-ansible.yml")],
                 ignore_limit=True,
                 tags="config",
+                check=False,
             ),
             mock.call(
                 mock.ANY,
@@ -1817,6 +1846,7 @@ class TestCase(unittest.TestCase):
                                               "kolla-openstack.yml"),
                 ],
                 ignore_limit=True,
+                check=False,
             ),
             mock.call(
                 mock.ANY,
@@ -1873,6 +1903,7 @@ class TestCase(unittest.TestCase):
                 [utils.get_data_files_path("ansible", "kolla-ansible.yml")],
                 ignore_limit=True,
                 tags=None,
+                check=False,
             ),
             mock.call(
                 mock.ANY,
@@ -1881,6 +1912,7 @@ class TestCase(unittest.TestCase):
                                               "kolla-openstack.yml"),
                 ],
                 ignore_limit=True,
+                check=False,
             ),
             mock.call(
                 mock.ANY,
@@ -2140,6 +2172,25 @@ class TestCase(unittest.TestCase):
         ]
         self.assertListEqual(expected_calls, mock_run.call_args_list)
 
+    @mock.patch.object(commands.KayobeAnsibleMixin,
+                       "run_kayobe_playbooks")
+    def test_baremetal_compute_register(self, mock_run):
+        command = commands.BaremetalComputeRegister(TestApp(), [])
+        parser = command.get_parser("test")
+        parsed_args = parser.parse_args([])
+        result = command.run(parsed_args)
+        self.assertEqual(0, result)
+        expected_calls = [
+            mock.call(
+                mock.ANY,
+                [
+                    utils.get_data_files_path(
+                        "ansible", "baremetal-compute-register.yml"),
+                ],
+            ),
+        ]
+        self.assertListEqual(expected_calls, mock_run.call_args_list)
+
     @mock.patch.object(commands.KayobeAnsibleMixin,
                        "run_kayobe_playbooks")
     def test_baremetal_compute_inspect(self, mock_run):
@@ -2366,29 +2417,31 @@ class TestHookDispatcher(unittest.TestCase):
 
     maxDiff = None
 
-    @mock.patch('kayobe.cli.commands.os.path')
-    def test_hook_ordering(self, mock_path):
+    @mock.patch.object(os.path, 'realpath')
+    def test_hook_ordering(self, mock_realpath):
         mock_command = mock.MagicMock()
         dispatcher = commands.HookDispatcher(command=mock_command)
         dispatcher._find_hooks = mock.MagicMock()
+        # Include multiple hook directories to show that they don't influence
+        # the order.
         dispatcher._find_hooks.return_value = [
-            "10-hook.yml",
-            "5-hook.yml",
-            "z-test-alphabetical.yml",
-            "10-before-hook.yml",
-            "5-multiple-dashes-in-name.yml",
-            "no-prefix.yml"
+            "config/path/10-hook.yml",
+            "config/path/5-hook.yml",
+            "config/path/z-test-alphabetical.yml",
+            "env/path/10-before-hook.yml",
+            "env/path/5-multiple-dashes-in-name.yml",
+            "env/path/no-prefix.yml"
         ]
         expected_result = [
-            "5-hook.yml",
-            "5-multiple-dashes-in-name.yml",
-            "10-before-hook.yml",
-            "10-hook.yml",
-            "no-prefix.yml",
-            "z-test-alphabetical.yml",
+            "config/path/5-hook.yml",
+            "env/path/5-multiple-dashes-in-name.yml",
+            "env/path/10-before-hook.yml",
+            "config/path/10-hook.yml",
+            "env/path/no-prefix.yml",
+            "config/path/z-test-alphabetical.yml",
         ]
-        mock_path.realpath.side_effect = lambda x: x
-        actual = dispatcher.hooks("config/path", "pre", None)
+        mock_realpath.side_effect = lambda x: x
+        actual = dispatcher.hooks(["config/path", "env/path"], "pre", None)
         self.assertListEqual(actual, expected_result)
 
     @mock.patch('kayobe.cli.commands.os.path')
@@ -2405,7 +2458,7 @@ class TestHookDispatcher(unittest.TestCase):
             "z-test-alphabetical.yml",
         ]
         mock_path.realpath.side_effect = lambda x: x
-        actual = dispatcher.hooks("config/path", "pre", "all")
+        actual = dispatcher.hooks(["config/path"], "pre", "all")
         self.assertListEqual(actual, [])
 
     @mock.patch('kayobe.cli.commands.os.path')
@@ -2429,6 +2482,105 @@ class TestHookDispatcher(unittest.TestCase):
             "z-test-alphabetical.yml",
         ]
         mock_path.realpath.side_effect = lambda x: x
-        actual = dispatcher.hooks("config/path", "pre",
+        actual = dispatcher.hooks(["config/path"], "pre",
                                   "5-multiple-dashes-in-name.yml")
         self.assertListEqual(actual, expected_result)
+
+    @mock.patch.object(glob, 'glob')
+    @mock.patch.object(os.path, 'exists')
+    def test__find_hooks(self, mock_exists, mock_glob):
+        mock_exists.return_value = True
+        mock_command = mock.MagicMock()
+        dispatcher = commands.HookDispatcher(command=mock_command)
+        mock_glob.return_value = [
+            "config/path/hooks/pre.d/1-hook.yml",
+            "config/path/hooks/pre.d/5-hook.yml",
+            "config/path/hooks/pre.d/10-hook.yml",
+        ]
+        expected_result = [
+            "config/path/hooks/pre.d/1-hook.yml",
+            "config/path/hooks/pre.d/10-hook.yml",
+            "config/path/hooks/pre.d/5-hook.yml",
+        ]
+        actual = dispatcher._find_hooks(["config/path"], "pre")
+        # Sort the result - it is not ordered at this stage.
+        actual.sort()
+        self.assertListEqual(actual, expected_result)
+
+    @mock.patch.object(glob, 'glob')
+    @mock.patch.object(os.path, 'exists')
+    def test__find_hooks_with_env(self, mock_exists, mock_glob):
+        mock_exists.return_value = True
+        mock_command = mock.MagicMock()
+        dispatcher = commands.HookDispatcher(command=mock_command)
+        mock_glob.side_effect = [
+            [
+                "config/path/hooks/pre.d/all.yml",
+                "config/path/hooks/pre.d/base-only.yml",
+            ],
+            [
+                "env/path/hooks/pre.d/all.yml",
+                "env/path/hooks/pre.d/env-only.yml",
+            ]
+        ]
+        expected_result = [
+            "config/path/hooks/pre.d/base-only.yml",
+            "env/path/hooks/pre.d/all.yml",
+            "env/path/hooks/pre.d/env-only.yml",
+        ]
+        actual = dispatcher._find_hooks(["config/path", "env/path"], "pre")
+        # Sort the result - it is not ordered at this stage.
+        actual.sort()
+        self.assertListEqual(actual, expected_result)
+
+    @mock.patch.object(glob, 'glob')
+    @mock.patch.object(os.path, 'exists')
+    def test__find_hooks_with_nested_envs(self, mock_exists, mock_glob):
+        mock_exists.return_value = True
+        mock_command = mock.MagicMock()
+        dispatcher = commands.HookDispatcher(command=mock_command)
+        mock_glob.side_effect = [
+            [
+                "config/path/hooks/pre.d/all.yml",
+                "config/path/hooks/pre.d/base-only.yml",
+                "config/path/hooks/pre.d/base-env1.yml",
+                "config/path/hooks/pre.d/base-env2.yml",
+            ],
+            [
+                "env1/path/hooks/pre.d/all.yml",
+                "env1/path/hooks/pre.d/env1-only.yml",
+                "env1/path/hooks/pre.d/base-env1.yml",
+                "env1/path/hooks/pre.d/env1-env2.yml",
+            ],
+            [
+                "env2/path/hooks/pre.d/all.yml",
+                "env2/path/hooks/pre.d/env2-only.yml",
+                "env2/path/hooks/pre.d/base-env2.yml",
+                "env2/path/hooks/pre.d/env1-env2.yml",
+            ]
+        ]
+        expected_result = [
+            "config/path/hooks/pre.d/base-only.yml",
+            "env1/path/hooks/pre.d/base-env1.yml",
+            "env1/path/hooks/pre.d/env1-only.yml",
+            "env2/path/hooks/pre.d/all.yml",
+            "env2/path/hooks/pre.d/base-env2.yml",
+            "env2/path/hooks/pre.d/env1-env2.yml",
+            "env2/path/hooks/pre.d/env2-only.yml",
+        ]
+        actual = dispatcher._find_hooks(["config/path", "env1/path",
+                                         "env2/path"], "pre")
+        # Sort the result - it is not ordered at this stage.
+        actual.sort()
+        self.assertListEqual(actual, expected_result)
+
+    @mock.patch.object(glob, 'glob')
+    @mock.patch.object(os.path, 'exists')
+    def test__find_hooks_non_existent(self, mock_exists, mock_glob):
+        mock_exists.return_value = False
+        mock_command = mock.MagicMock()
+        dispatcher = commands.HookDispatcher(command=mock_command)
+        expected_result = []
+        actual = dispatcher._find_hooks(["config/path"], "pre")
+        self.assertListEqual(actual, expected_result)
+        mock_glob.assert_not_called()
