@@ -25,6 +25,11 @@ def _net_interface(context, name):
     return context.get(name + '_interface')
 
 
+@jinja2.pass_context
+def _net_parent(context, name):
+    return context.get(name + '_parent')
+
+
 @jinja2.pass_context
 def _net_vlan(context, name):
     return context.get(name + '_vlan')
@@ -42,6 +47,7 @@ class FakeTemplar(object):
         self.variables = variables
         self.env = jinja2.Environment()
         self.env.filters['net_interface'] = _net_interface
+        self.env.filters['net_parent'] = _net_parent
         self.env.filters['net_vlan'] = _net_vlan
         self.env.filters['net_select_bridges'] = _net_select_bridges
 
@@ -130,26 +136,6 @@ class TestCase(unittest.TestCase):
         }
         self.assertEqual(expected, result)
 
-    def test__run_one_with_dashes(self):
-        variables = copy.deepcopy(self.variables)
-        variables["foo_interface"] = "eth-0"
-        module = self._create_module(variables)
-        interfaces = [{
-            "var_name": "kolla_foo_interface",
-            "network": "foo",
-            "description": "Foo network",
-            "required": False,
-        }]
-        result = module._run(interfaces, [])
-        expected = {
-            "changed": False,
-            "ansible_facts": {
-                "kolla_foo_interface": "eth_0",
-            },
-            "_ansible_facts_cacheable": False,
-        }
-        self.assertEqual(expected, result)
-
     def test__run_interface_not_mapped(self):
         module = self._create_module()
         interfaces = [{
